/**
 * @copyright Cube Dev, Inc.
 * @license Apache-2.0
 * @fileoverview The `MSSqlDriver` and related types declaration.
 */
import { config as MsSQLConfig } from 'mssql';
import { BaseDriver, DriverInterface, StreamOptions, DownloadQueryResultsOptions, TableStructure, DriverCapabilities, DownloadQueryResultsResult } from '@cubejs-backend/base-driver';
import { QueryStream } from './QueryStream';
export type MSSqlDriverConfiguration = Omit<MsSQLConfig, 'server'> & {
    readOnly?: boolean;
    server?: string;
};
/**
 * MS SQL driver class.
 */
export declare class MSSqlDriver extends BaseDriver implements DriverInterface {
    private readonly connectionPool;
    private readonly initialConnectPromise;
    private readonly config;
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    /**
     * Class constructor.
     */
    constructor(config?: MSSqlDriverConfiguration & {
        /**
         * Data source name.
         */
        dataSource?: string;
        /**
         * Max pool size value for the [cube]<-->[db] pool.
         */
        maxPoolSize?: number;
        /**
         * Time to wait for a response from a connection after validation
         * request before determining it as not valid. Default - 10000 ms.
         */
        testConnectionTimeout?: number;
        server?: string;
    });
    /**
     * Returns the configurable driver options
     * Note: It returns the unprefixed option names.
     * In case of using multi sources options need to be prefixed manually.
     */
    static driverEnvVariables(): string[];
    testConnection(): Promise<void>;
    /**
     * Executes query in streaming mode.
     *
     * @param {string} query
     * @param {Array} values
     * @param {{ highWaterMark: number? }} options
     * @return {Promise<StreamTableDataWithTypes>}
     */
    stream(query: string, values: unknown[], { highWaterMark }: StreamOptions): Promise<{
        rowStream: QueryStream;
        types: TableStructure;
        release: () => Promise<void>;
    }>;
    /**
     * @param {{
     *   [name: string]: {
     *     index: number,
     *     name: string,
     *     type: *,
     *     nullable: boolean,
     *     caseSensitive: boolean,
     *     identity: boolean,
     *     readOnly: boolean,
     *     length: number?,
     *     scale: number?,
     *     precision: number?
     *   }
     * }} fields
     */
    private mapFields;
    query(query: string, values: unknown[]): Promise<any>;
    param(paramIndex: number): string;
    tableColumnTypes(table: string): Promise<TableStructure>;
    getTablesQuery(schemaName: string): Promise<any>;
    createSchemaIfNotExists(schemaName: string): Promise<void>;
    informationSchemaQuery(): string;
    downloadQueryResults(query: string, values: unknown[], options: DownloadQueryResultsOptions): Promise<DownloadQueryResultsResult>;
    protected fromGenericType(columnType: string): string;
    protected toGenericType(columnType: string): string;
    readOnly(): boolean;
    wrapQueryWithLimit(query: {
        query: string;
        limit: number;
    }): void;
    capabilities(): DriverCapabilities;
}
//# sourceMappingURL=MSSqlDriver.d.ts.map